Prover

Struct Prover 

pub struct Prover<P, H>{ /* private fields */ }
Struct for proving instances of a particular constraint system.

The Self::setup constructor pre-processes reusable structures for proving instances of the given constraint system. Then Self::prove is called one or more times with individual instances.

Implementations

Source

impl<F, P, H> Prover<P, H>
where F: BinaryField, P: PackedField<Scalar = F>, H: ParallelHashSuite, Output<H::LeafHash>: SerializeBytes,

pub fn setup(verifier: &Verifier<F, H>) -> Result<Self, Error>

Constructs a prover corresponding to a constraint system verifier.

See Prover struct documentation for details.

pub const fn iop_prover(&self) -> &IOPProver<P::Scalar>

Returns a reference to the IOP prover.

pub const fn iop_compiler( &self, ) -> &BaseFoldProverCompiler<P, NeighborsLastMultiThread<GaoMateerPreExpanded<F>>>

Returns a reference to the BaseFold ZK prover compiler.

pub fn prove<Challenger_: Challenger>( &self, witness: &Witness<F>, rng: impl CryptoRng, transcript: &mut ProverTranscript<Challenger_>, ) -> Result<(), Error>

Generates a proof for a witness against the constraint system.

Arguments
  • witness - The witness values for the constraint system
  • rng - Random number generator for blinding
  • transcript - The prover transcript for Fiat-Shamir
Preconditions
  • The witness length must match the constraint system size