pub struct Prover<P, H>{ /* private fields */ }Expand description
Struct for proving instances of a particular constraint system.
The Self::setup constructor pre-processes reusable structures for proving instances of the
given constraint system. Then Self::prove is called one or more times with individual
instances.
Implementations
Sourceimpl<F, P, H> Prover<P, H>where
F: BinaryField,
P: PackedField<Scalar = F>,
H: ParallelHashSuite,
Output<H::LeafHash>: SerializeBytes,
impl<F, P, H> Prover<P, H>where
F: BinaryField,
P: PackedField<Scalar = F>,
H: ParallelHashSuite,
Output<H::LeafHash>: SerializeBytes,
Sourcepub fn setup(verifier: &Verifier<F, H>) -> Result<Self, Error>
pub fn setup(verifier: &Verifier<F, H>) -> Result<Self, Error>
Constructs a prover corresponding to a constraint system verifier.
See Prover struct documentation for details.
Sourcepub const fn iop_prover(&self) -> &IOPProver<P::Scalar>
pub const fn iop_prover(&self) -> &IOPProver<P::Scalar>
Returns a reference to the IOP prover.
Sourcepub const fn iop_compiler(
&self,
) -> &BaseFoldProverCompiler<P, NeighborsLastMultiThread<GaoMateerPreExpanded<F>>>
pub const fn iop_compiler( &self, ) -> &BaseFoldProverCompiler<P, NeighborsLastMultiThread<GaoMateerPreExpanded<F>>>
Returns a reference to the BaseFold ZK prover compiler.
Sourcepub fn prove<Challenger_: Challenger>(
&self,
witness: &Witness<F>,
rng: impl CryptoRng,
transcript: &mut ProverTranscript<Challenger_>,
) -> Result<(), Error>
pub fn prove<Challenger_: Challenger>( &self, witness: &Witness<F>, rng: impl CryptoRng, transcript: &mut ProverTranscript<Challenger_>, ) -> Result<(), Error>